CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
101 lines
2.7 KiB
C++
101 lines
2.7 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <resource_guards.hh>
|
|
|
|
/**
|
|
* @addtogroup hipGetStreamDeviceId hipGetStreamDeviceId
|
|
* @{
|
|
* @ingroup CallbackTest
|
|
* `hipGetStreamDeviceId(hipStream_t stream)` -
|
|
* returns the ID of the device on which the stream is active
|
|
*/
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Creates a new stream for each available device
|
|
* - Verifies that the Device Stream ID is equal to the Device ID
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/callback/hipGetStreamDeviceId.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
* - Platform specific (AMD)
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipGetStreamDeviceId_Positive_Threaded_Basic) {
|
|
int id = GENERATE(range(0, HipTest::getDeviceCount()));
|
|
HIP_CHECK(hipSetDevice(id));
|
|
|
|
StreamGuard stream_guard{Streams::created};
|
|
REQUIRE(hipGetStreamDeviceId(stream_guard.stream()) == id);
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Creates a new stream for each available device, through multiple threads
|
|
* - Verifies that the Device Stream ID is equal to the Device ID, from each thread
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/callback/hipGetStreamDeviceId.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
* - Platform specific (AMD)
|
|
* - Multithreaded GPU
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipGetStreamDeviceId_Positive_Multithreaded_Basic) {
|
|
const unsigned int max_threads = std::thread::hardware_concurrency();
|
|
const int device_count = HipTest::getDeviceCount();
|
|
|
|
auto thread_function = [&]() {
|
|
for (int id = 0; id < device_count; ++id) {
|
|
HIP_CHECK_THREAD(hipSetDevice(id));
|
|
|
|
StreamGuard stream_guard{Streams::perThread};
|
|
REQUIRE_THREAD(hipGetStreamDeviceId(stream_guard.stream()) == id);
|
|
}
|
|
};
|
|
|
|
std::vector<std::thread> thread_pool;
|
|
for (unsigned int i = 0; i < max_threads; ++i) {
|
|
thread_pool.emplace_back(thread_function);
|
|
}
|
|
|
|
for (auto& thread : thread_pool) {
|
|
thread.join();
|
|
}
|
|
|
|
HIP_CHECK_THREAD_FINALIZE();
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Checks that function returns valid ID if the stream is `nullptr`
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/callback/hipGetStreamDeviceId.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
* - Platform specific (AMD)
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipGetStreamDeviceId_Negative_Parameters) {
|
|
int id = GENERATE(range(0, HipTest::getDeviceCount()));
|
|
HIP_CHECK(hipSetDevice(id));
|
|
|
|
StreamGuard stream_guard{Streams::nullstream};
|
|
REQUIRE(hipGetStreamDeviceId(stream_guard.stream()) == id);
|
|
}
|
|
|
|
/**
|
|
* End doxygen group CallbackTest.
|
|
* @}
|
|
*/
|